#!/bin/sh

# This script automatically makes release bundle for LSB Application Testkit

# Setup
PACKAGE="lsb-atk-manager"
VER="1.2.3"
RELEASE="1"

# Derive date string for daily snapshots
ISO_DATE=`date +"%Y%m%d"`
PWD=`pwd`

FULL_PACKAGE_NAME="$PACKAGE-$VER"

# Handle different version generation for snapshots than for official builds
# OFFICIAL_RELEASE should be set to the tag to extract from BZR
if [ -z "$OFFICIAL_RELEASE" ]; then
	VERSION_SUFFIX=".$ISO_DATE"
	EXPORT_TAG=""
else
	VERSION_SUFFIX=""
	# EXPORT_TAG should be set to the BZR tag to use
	EXPORT_TAG="--revision=otag:$OFFICIAL_RELEASE"
fi

# Determine whether to use rpm or rpmbuild to build the packages
if [ -f /usr/bin/rpmbuild ]; then
	RPM_BUILD_CMD="rpmbuild"
else
	RPM_BUILD_CMD="rpm"
fi

# Get RPM configuration information
# NOTE THAT RPM_TMP_BUILD_DIR IS DELETED AFTER THE RPM BUILD IS COMPLETED
RCFILELIST="/usr/lib/rpm/rpmrc:./rpmrc"
RPM_TMP_BUILD_DIR="/var/tmp/rpm-build"
RPM_BUILD_ARCH=$(rpm --rcfile ${RCFILELIST} --eval=%{_target_cpu})
LSB_ARCH=${RPM_BUILD_ARCH/%amd64/x86-64}
LSB_ARCH=${LSB_ARCH/%x86_64/x86-64}
LSB_ARCH=${LSB_ARCH/%i[3-6]86/ia32}
LSB_ARCH=${LSB_ARCH/%x86/ia32}
LSB_ARCH=${LSB_ARCH/%ppc/ppc32}
RPM_BINARY_DIR="$RPM_TMP_BUILD_DIR/RPMS/$RPM_BUILD_ARCH"
RPM_BINARY_NAME="$FULL_PACKAGE_NAME-$RELEASE.$RPM_BUILD_ARCH.rpm"

# Override this on the command line to use a different repo
if [ -z "$BZRTREES" ]; then
	BZRTREES="http://bzr.linux-foundation.org/lsb/devel"
fi
BZR_MODULE="atk-manager"

bzr export $EXPORT_TAG $FULL_PACKAGE_NAME $BZRTREES/$BZR_MODULE
cd $FULL_PACKAGE_NAME/utils
./lsb_info.pl 3.0 $LSB_ARCH
./lsb_info.pl 3.1 $LSB_ARCH
./lsb_info.pl 3.2 $LSB_ARCH
rm ./lsb_info.pl
cd ../..
tar czf $FULL_PACKAGE_NAME.src.tgz $FULL_PACKAGE_NAME
rm -rf $FULL_PACKAGE_NAME

mkdir -p $RPM_TMP_BUILD_DIR/BUILD
mkdir -p $RPM_TMP_BUILD_DIR/RPMS
cp ./rpmmacros ~/.rpmmacros

if (( $SIGN_PACKAGES )); then
	expect -c 'set timeout -1' -c "spawn $RPM_BUILD_CMD --sign --rcfile $RCFILELIST --define=_sourcedir\ $PWD --define=_topdir\ $RPM_TMP_BUILD_DIR --define=_target_cpu\ $RPM_BUILD_ARCH --define=name\ $PACKAGE --define=ver\ $VER --define=rel\ $RELEASE -bb $PACKAGE.spec" -c 'expect -ex "Enter pass phrase:"' -c 'send "\n"' -c 'expect "Executing(%clean)"' -c 'expect "exit 0"' -c 'send "\n"'
else
	$RPM_BUILD_CMD --rcfile $RCFILELIST --define="_sourcedir $PWD" --define="_topdir $RPM_TMP_BUILD_DIR" --define="_target_cpu $RPM_BUILD_ARCH" --define="name $PACKAGE" --define="ver $VER" --define="rel $RELEASE" -bb $PACKAGE.spec
fi

mv $RPM_BINARY_DIR/$RPM_BINARY_NAME .
rm -rf $RPM_TMP_BUILD_DIR

if !(( $BUILD_NO_DEB )); then
	if [ ! -f fakeroot ]; then
		echo "Error: fakeroot not found. Can't build DEB."
	elif [ ! -f alien ]; then
		echo "Error: alien not found. Can't build DEB."
	else
		fakeroot alien -cdk $RPM_BINARY_NAME
	fi
fi
